@@ -63,11 +63,11 @@ def unpack_absolute_path(paths_tuple):
 
 
 def validate_imports(files, allowed_imports_set):
-    """ This function returns paths of files which match the values in ./data/non_exposed_modules.json file
+    """ This function returns paths of files which have require/define statements not present in the allowed imports set
 
         @param:
         files <Array>: Array of file paths
-        allowed_imports_set <Set>: Set of file path imports formed from ./data/non_exposed_modules.json
+        allowed_imports_set <Set>: Set of file path imports
 
         Returns
 
@@ -88,7 +88,7 @@ def validate_imports(files, allowed_imports_set):
             "routers/AuthenticationUsers",
         ]
 
-        Let's assume a.py and c.py have the lines routers/SavedSearches and routers/AuthenticationUsers respectively this would then return a.py and c.py
+        Let's assume a.py and c.py have the lines routers/SavedSearches and routers/AuthenticationUsers respectively this would then return b.py and d.py
 
         returns
 
@@ -100,7 +100,7 @@ def validate_imports(files, allowed_imports_set):
             with open(filepath, "r", encoding='utf-8') as my_file:
                 matches = get_imported_matches(my_file.read())
                 for match in matches:
-                    if match in allowed_imports_set:
+                    if match not in allowed_imports_set:
                         improper_files.append((filepath, match))
     except Exception as exception:
         print("Exception while validating imports {}".format(exception))
@@ -127,9 +127,12 @@ def get_imported_matches(file):
         ['jquery', 'underscore', 'splunkjs/mvc', 'util/console']
     """
     matches = []
-    pattern = re.compile(r"((require|define)\(\[)((?:\n.+)+)(])|(require|define)\((.*)\)")
+    pattern = re.compile(
+        r"(require|define)(\s)*\((\s)*\[[^\[]+\]|(require|define)(\s)*\((\n|.)*\)")
     for matched_object in pattern.finditer(file):
-        imported_matches = re.finditer(r"['\"]([^'\"]*)['\"]", matched_object.group())
+        imported_matches = re.finditer(
+            r"['\"]([^'\"]*)['\"]",
+            matched_object.group())
         for imported in imported_matches:
             matches.append(imported.group(1))
     return matches
@@ -189,3 +192,11 @@ def populate_set_from_json(file_path):
         print("Error while loading json to a set. {}".format(exception))
 
     return json_set
+
+def handle_multiple_scripts(scripts):
+    seperated_scripts = []
+    multiple_scripts = scripts.split(',')
+    for script in multiple_scripts:
+        seperated_scripts.append(script.strip())
+
+    return seperated_scripts
\ No newline at end of file
