@@ -428,7 +428,7 @@ For example:
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
     """
@@ -461,7 +461,7 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
                 "TRANSFORMS-"
             ) and not setting.name.startswith("SEDCMD"):
                 reporter_output = "Only TRANSFORMS- or SEDCMD options are allowed for pretrained sourcetypes."
-                reporter.fail(reporter_output, props_file_path, setting.lineno)
+                reporter.warn(reporter_output, props_file_path, setting.lineno)
                 return
 
             if setting.name.startswith("TRANSFORMS-"):
@@ -469,7 +469,7 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
                     reporter_output = (
                         "No transforms.conf exists for setting in props.conf: {}={}"
                     ).format(setting.name, setting.value)
-                    reporter.fail(reporter_output, props_file_path, setting.lineno)
+                    reporter.warn(reporter_output, props_file_path, setting.lineno)
                     return
 
                 transforms_conf = app.transforms_conf()
@@ -486,7 +486,7 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
                             setting.name,
                             setting.value,
                         )
-                        reporter.fail(reporter_output, props_file_path, setting.lineno)
+                        reporter.warn(reporter_output, props_file_path, setting.lineno)
                         return
 
                     # the transforms may only modify the allowed fields
@@ -500,7 +500,7 @@ def check_pretrained_sourcetypes_have_only_allowed_transforms(app, reporter):
                                 "Modifying the {} field for a pretrained"
                                 "sourcetype is not allowed."
                             ).format(dest.value)
-                            reporter.fail(
+                            reporter.warn(
                                 reporter_output, transforms_file_path, dest.lineno
                             )
 
