@@ -1,4 +1,4 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
 
 """
 ### Support requirements
@@ -6,6 +6,7 @@
 
 # Python Standard Libraries
 import logging
+
 # Custom Libraries
 import splunk_appinspect
 
@@ -13,10 +14,10 @@ report_display_order = 60
 logger = logging.getLogger(__name__)
 
 
-@splunk_appinspect.tags('splunk_appinspect', 'manual', 'appapproval', 'markdown')
-@splunk_appinspect.cert_version(min='1.0.0')
+@splunk_appinspect.tags("splunk_appinspect", "manual", "appapproval", "markdown")
+@splunk_appinspect.cert_version(min="1.0.0")
 @splunk_appinspect.display(report_display_order=10)
-def check_link_includes_contact_info(app, reporter):
+def check_link_includes_contact_info(reporter):
     """Check that the app's documentation lists contact information and level
     of support for the app.  Any level of support is acceptable for developer
     supported apps, as long as it is clearly declared in documentation.
